@@ -117,10 +117,12 @@
  * to the URL and will be set when the Connection is created. In addition
  * to pragmas, the following properties are supported:
  *
- * - `heap_limit=value` - Make SQLite auto-release unused memory
- *   if memory usage goes above the specified value [KB].
  * - `serialized=true` - Make SQLite switch to serialized mode
  *   if value is true, otherwise multi-thread mode is used (the default).
+ * - `shared-cache=true` - Make SQLite use shared-cache if value is true.
+ *   Using shared cache can significantly reduce database lock errors in
+ *   some scenarios where two or more connections might write to the database.
+ *   It is also recommended to build libsqlite and libzdb with unlock  notify.
  *
  * A URL for connecting to a SQLite database might look like this (with recommended pragmas):
  *
@@ -249,6 +251,19 @@
 #define T ConnectionPool_T
 typedef struct ConnectionPool_S *T;
 
+/**
+ * @brief Enumerates the supported database types for ConnectionPool
+ *
+ * This enum defines the various database backends that can be used
+ * with the ConnectionPool in the libzdb library.
+ */
+typedef enum {
+        CONNECTIONPOOL_NONE = 0,   /**< No database type set (default/uninitialized state) */
+        CONNECTIONPOOL_SQLITE,     /**< SQLite database connection */
+        CONNECTIONPOOL_MYSQL,      /**< MySQL database connection */
+        CONNECTIONPOOL_POSTGRESQL, /**< PostgreSQL database connection */
+        CONNECTIONPOOL_ORACLE      /**< Oracle database connection */
+} CONNECTIONPOOL_TYPE;
 
 /**
  * Library Debug flag. If set to true, emit debug output
@@ -281,6 +296,16 @@ void ConnectionPool_free(T *P);
 /// @name Properties
 /// @{
 
+/**
+ * @brief Retrieves the database type for this ConnectionPool
+ *
+ * @param P A ConnectionPool object
+ * @return The CONNECTIONPOOL_TYPE representing the database backend for this ConnectionPool
+ * @see CONNECTIONPOOL_TYPE
+ */
+CONNECTIONPOOL_TYPE ConnectionPool_getType(T P);
+
+
 /**
  * @brief Returns this Connection Pool's URL
  * @param P A ConnectionPool object
