@@ -3,12 +3,12 @@
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 3.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
@@ -28,11 +28,11 @@
 #include "system/Time.h"
 
 /**
- * This interface defines the <b>contract</b> for the concrete database 
+ * This interface defines the <b>contract</b> for the concrete database
  * implementation used for delegation in the ResultSet class.
  *
  * @file
- */ 
+ */
 
 #define T ResultSetDelegate_T
 typedef struct T *T;
@@ -43,8 +43,10 @@ typedef struct Rop_T {
         int (*getColumnCount)(T R);
         const char *(*getColumnName)(T R, int columnIndex);
         long (*getColumnSize)(T R, int columnIndex);
-        int (*next)(T R);
-        int (*isnull)(T R, int columnIndex);
+        void (*setFetchSize)(T R, int rows);
+        int (*getFetchSize)(T R);
+        bool (*next)(T R);
+        bool (*isnull)(T R, int columnIndex);
         const char *(*getString)(T R, int columnIndex);
         const void *(*getBlob)(T R, int columnIndex, int *size);
         time_t (*getTimestamp)(T R, int columnIndex);
