@@ -289,11 +289,6 @@ static bool _beginTransactionType(T C, TRANSACTION_TYPE type) {
 }
 
 
-static bool _beginTransaction(T C) {
-    return _beginTransactionType(C, TRANSACTION_DEFAULT);
-}
-
-
 static bool _commit(T C) {
         assert(C);
         C->lastError = OCITransCommit(C->svc, C->err, OCI_DEFAULT);
@@ -454,7 +449,6 @@ const struct Cop_T oraclesqlcops = {
         .free                   = _free,
         .ping                   = _ping,
         .setQueryTimeout        = _setQueryTimeout,
-        .beginTransaction       = _beginTransaction,
         .beginTransactionType   = _beginTransactionType,
         .commit                 = _commit,
         .rollback               = _rollback,
