@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2010-2013 Volodymyr Tarasenko <tvntsr@yahoo.com>
- *              2010      Sergey Pavlov <sergey.pavlov@gmail.com>
- *              2010      PortaOne Inc.
+ *               2010      Sergey Pavlov <sergey.pavlov@gmail.com>
+ *               2010      PortaOne Inc.
  * Copyright (C) Tildeslash Ltd. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -21,7 +21,7 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  * THE SOFTWARE.
- */ 
+ */
 
 #include "Config.h"
 
@@ -29,21 +29,13 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <oci.h>
-
-#include "URL.h"
-#include "ResultSet.h"
+#include "OracleAdapter.h"
 #include "StringBuffer.h"
-#include "PreparedStatement.h"
-#include "OracleResultSet.h"
-#include "OraclePreparedStatement.h"
-#include "ConnectionDelegate.h"
-#include "OracleConnection.h"
 
 
 /**
- * Implementation of the ResulSet/Delegate interface for oracle. 
- * 
+ * Implementation of the ResulSet/Delegate interface for oracle.
+ *
  * @file
  */
 
@@ -51,18 +43,6 @@
 /* ----------------------------------------------------------- Definitions */
 
 
-const struct Rop_T oraclerops = {
-	.name           = "oracle",
-        .free           = OracleResultSet_free,
-        .getColumnCount = OracleResultSet_getColumnCount,
-        .getColumnName  = OracleResultSet_getColumnName,
-        .getColumnSize  = OracleResultSet_getColumnSize,
-        .next           = OracleResultSet_next,
-        .isnull         = OracleResultSet_isnull,
-        .getString      = OracleResultSet_getString,
-        .getBlob        = OracleResultSet_getBlob
-        // getTimestamp and getDateTime is handled in ResultSet
-};
 typedef struct column_t {
         OCIDefine *def;
         int isNull;
@@ -70,13 +50,14 @@ typedef struct column_t {
         char *name;
         unsigned long length;
         OCILobLocator *lob_loc;
-        OCIDateTime   *date; 
+        OCIDateTime   *date;
 } *column_t;
 #define T ResultSetDelegate_T
 struct T {
         int         columnCount;
-        int         row;
-        ub4         maxRow;
+        int         currentRow;
+        int         fetchSize;
+        ub4         maxRows;
         OCIStmt*    stmt;
         OCIEnv*     env;
         OCISession* usr;
@@ -85,8 +66,8 @@ struct T {
         column_t    columns;
         sword       lastError;
         int         freeStatement;
+        Connection_T delegator;
 };
-
 #ifndef ORACLE_COLUMN_NAME_LOWERCASE
 #define ORACLE_COLUMN_NAME_LOWERCASE 2
 #endif
@@ -97,49 +78,49 @@ struct T {
 /* ------------------------------------------------------- Private methods */
 
 
-static int _initaleDefiningBuffers(T R) {
+static bool _initaleDefiningBuffers(T R) {
         ub2 dtype = 0;
         int deptlen;
         int sizelen = sizeof(deptlen);
         OCIParam* pard = NULL;
-        sword status;
+        __attribute__((unused)) sword status;
         for (int i = 1; i <= R->columnCount; i++) {
-                 deptlen = 0;
+                deptlen = 0;
                 /* The next two statements describe the select-list item, dname, and
                  return its length */
                 R->lastError = OCIParamGet(R->stmt, OCI_HTYPE_STMT, R->err, (void **)&pard, i);
-                if (R->lastError != OCI_SUCCESS) 
+                if (R->lastError != OCI_SUCCESS)
                         return false;
                 R->lastError = OCIAttrGet(pard, OCI_DTYPE_PARAM, &deptlen, &sizelen, OCI_ATTR_DATA_SIZE, R->err);
-                if (R->lastError != OCI_SUCCESS) { 
+                if (R->lastError != OCI_SUCCESS) {
                         // cannot get column's size, cleaning and returning
                         OCIDescriptorFree(pard, OCI_DTYPE_PARAM);
                         return false;
                 }
-                OCIAttrGet(pard, OCI_DTYPE_PARAM, &dtype, 0, OCI_ATTR_DATA_TYPE, R->err); 
+                OCIAttrGet(pard, OCI_DTYPE_PARAM, &dtype, 0, OCI_ATTR_DATA_TYPE, R->err);
                 /* Use the retrieved length of dname to allocate an output buffer, and
                  then define the output variable. */
                 deptlen +=1;
                 R->columns[i-1].length = deptlen;
                 R->columns[i-1].isNull = 0;
-                switch(dtype) 
+                switch(dtype)
                 {
                         case SQLT_BLOB:
                                 R->columns[i-1].buffer = NULL;
                                 status = OCIDescriptorAlloc((dvoid *)R->env, (dvoid **) &(R->columns[i-1].lob_loc),
-                                                (ub4) OCI_DTYPE_LOB,
-                                                (size_t) 0, (dvoid **) 0);
-                                R->lastError = OCIDefineByPos(R->stmt, &R->columns[i-1].def, R->err, i, 
-                                        &(R->columns[i-1].lob_loc), deptlen, SQLT_BLOB, &(R->columns[i-1].isNull), 0, 0, OCI_DEFAULT);
+                                                            (ub4) OCI_DTYPE_LOB,
+                                                            (size_t) 0, (dvoid **) 0);
+                                R->lastError = OCIDefineByPos(R->stmt, &R->columns[i-1].def, R->err, i,
+                                                              &(R->columns[i-1].lob_loc), deptlen, SQLT_BLOB, &(R->columns[i-1].isNull), 0, 0, OCI_DEFAULT);
                                 break;
-
-                        case SQLT_CLOB: 
+                                
+                        case SQLT_CLOB:
                                 R->columns[i-1].buffer = NULL;
                                 status = OCIDescriptorAlloc((dvoid *)R->env, (dvoid **) &(R->columns[i-1].lob_loc),
-                                                (ub4) OCI_DTYPE_LOB,
-                                                (size_t) 0, (dvoid **) 0);
-                                R->lastError = OCIDefineByPos(R->stmt, &R->columns[i-1].def, R->err, i, 
-                                        &(R->columns[i-1].lob_loc), deptlen, SQLT_CLOB, &(R->columns[i-1].isNull), 0, 0, OCI_DEFAULT);
+                                                            (ub4) OCI_DTYPE_LOB,
+                                                            (size_t) 0, (dvoid **) 0);
+                                R->lastError = OCIDefineByPos(R->stmt, &R->columns[i-1].def, R->err, i,
+                                                              &(R->columns[i-1].lob_loc), deptlen, SQLT_CLOB, &(R->columns[i-1].isNull), 0, 0, OCI_DEFAULT);
                                 break;
                         case SQLT_DAT:
                         case SQLT_DATE:
@@ -148,22 +129,22 @@ static int _initaleDefiningBuffers(T R) {
                         case SQLT_TIMESTAMP_LTZ:
                                 R->columns[i-1].buffer = NULL;
                                 status = OCIDescriptorAlloc((dvoid *)R->env, (dvoid **) &(R->columns[i-1].date),
-                                                (ub4) OCI_DTYPE_TIMESTAMP,
-                                                (size_t) 0, (dvoid **) 0);
-                                R->lastError = OCIDefineByPos(R->stmt, &R->columns[i-1].def, R->err, i, 
-                                        &(R->columns[i-1].date), sizeof(R->columns[i-1].date), SQLT_TIMESTAMP, &(R->columns[i-1].isNull), 0, 0, OCI_DEFAULT);
+                                                            (ub4) OCI_DTYPE_TIMESTAMP,
+                                                            (size_t) 0, (dvoid **) 0);
+                                R->lastError = OCIDefineByPos(R->stmt, &R->columns[i-1].def, R->err, i,
+                                                              &(R->columns[i-1].date), sizeof(R->columns[i-1].date), SQLT_TIMESTAMP, &(R->columns[i-1].isNull), 0, 0, OCI_DEFAULT);
                                 break;
                         default:
                                 R->columns[i-1].lob_loc = NULL;
                                 R->columns[i-1].buffer = ALLOC(deptlen + 1);
-                                R->lastError = OCIDefineByPos(R->stmt, &R->columns[i-1].def, R->err, i, 
-                                        R->columns[i-1].buffer, deptlen, SQLT_STR, &(R->columns[i-1].isNull), 0, 0, OCI_DEFAULT);
+                                R->lastError = OCIDefineByPos(R->stmt, &R->columns[i-1].def, R->err, i,
+                                                              R->columns[i-1].buffer, deptlen, SQLT_STR, &(R->columns[i-1].isNull), 0, 0, OCI_DEFAULT);
                 }
                 {
                         char *col_name;
                         ub4   col_name_len;
                         char* tmp_buffer;
-
+                        
                         R->lastError = OCIAttrGet(pard, OCI_DTYPE_PARAM, &col_name, &col_name_len, OCI_ATTR_NAME, R->err);
                         if (R->lastError != OCI_SUCCESS)
                                 continue;
@@ -187,17 +168,17 @@ static int _initaleDefiningBuffers(T R) {
         return true;
 }
 
-static int _toString(T R, int i)
+static bool _toString(T R, int i)
 {
         const char fmt[] = "IYYY-MM-DD HH24.MI.SS"; // "YYYY-MM-DD HH24:MI:SS TZR TZD"
-
+        
         R->columns[i].length = DATE_STR_BUF_SIZE;
         if (R->columns[i].buffer)
                 FREE(R->columns[i].buffer);
-
+        
         R->columns[i].buffer = ALLOC(R->columns[i].length + 1);
-        R->lastError = OCIDateTimeToText(R->usr, 
-                                         R->err, 
+        R->lastError = OCIDateTimeToText(R->usr,
+                                         R->err,
                                          R->columns[i].date,
                                          fmt, strlen(fmt),
                                          0,
@@ -206,47 +187,47 @@ static int _toString(T R, int i)
         return ((R->lastError == OCI_SUCCESS) || (R->lastError == OCI_SUCCESS_WITH_INFO));;
 }
 
-
-/* ----------------------------------------------------- Protected methods */
+static void _setFetchSize(T R, int rows);
 
 
-#ifdef PACKAGE_PROTECTED
-#pragma GCC visibility push(hidden)
-#endif
+/* ------------------------------------------------------------- Constructor */
 
-T OracleResultSet_new(OCIStmt *stmt, OCIEnv *env, OCISession* usr, OCIError *err, OCISvcCtx *svc, int need_free, int max_row) {
+
+T OracleResultSet_new(Connection_T delegator, OCIStmt *stmt, OCIEnv *env, OCISession* usr, OCIError *err, OCISvcCtx *svc, int need_free) {
         T R;
         assert(stmt);
         assert(env);
         assert(err);
         assert(svc);
         NEW(R);
+        R->delegator = delegator;
         R->stmt = stmt;
         R->env  = env;
         R->err  = err;
         R->svc  = svc;
         R->usr  = usr;
+        R->maxRows = Connection_getMaxRows(R->delegator);
         R->freeStatement = need_free;
-        R->row = 0;
-        R->lastError = OCIAttrGet(R->stmt, OCI_HTYPE_STMT, &R->maxRow, NULL, OCI_ATTR_ROW_COUNT/*OCI_ATTR_ROWS_FETCHED*/, R->err);
-        if (R->lastError != OCI_SUCCESS && R->lastError != OCI_SUCCESS_WITH_INFO)
-                DEBUG("OracleResultSet_new: Error %d, '%s'\n", R->lastError, OraclePreparedStatement_getLastError(R->lastError,R->err));
         /* Get the number of columns in the select list */
         R->lastError = OCIAttrGet (R->stmt, OCI_HTYPE_STMT, &R->columnCount, NULL, OCI_ATTR_PARAM_COUNT, R->err);
         if (R->lastError != OCI_SUCCESS && R->lastError != OCI_SUCCESS_WITH_INFO)
-                DEBUG("OracleResultSet_new: Error %d, '%s'\n", R->lastError, OraclePreparedStatement_getLastError(R->lastError,R->err));
+                DEBUG("_new: Error %d, '%s'\n", R->lastError, OraclePreparedStatement_getLastError(R->lastError,R->err));
         R->columns = CALLOC(R->columnCount, sizeof (struct column_t));
         if (!_initaleDefiningBuffers(R)) {
-                DEBUG("OracleResultSet_new: Error %d, '%s'\n", R->lastError, OraclePreparedStatement_getLastError(R->lastError,R->err));
-                R->row = -1;
+                DEBUG("_new: Error %d, '%s'\n", R->lastError, OraclePreparedStatement_getLastError(R->lastError,R->err));
+                R->currentRow = -1;
+        }
+        if (R->currentRow != -1) {
+                _setFetchSize(R, Connection_getFetchSize(R->delegator));
         }
-        if ((max_row != 0) && ((R->maxRow > max_row) ||(R->maxRow == 0))) 
-                R->maxRow = max_row;
         return R;
 }
 
 
-void OracleResultSet_free(T *R) {
+/* -------------------------------------------------------- Delegate Methods */
+
+
+static void _free(T *R) {
         assert(R && *R);
         if ((*R)->freeStatement)
                 OCIHandleFree((*R)->stmt, OCI_HTYPE_STMT);
@@ -263,13 +244,13 @@ void OracleResultSet_free(T *R) {
 }
 
 
-int OracleResultSet_getColumnCount(T R) {
+static int _getColumnCount(T R) {
         assert(R);
         return R->columnCount;
 }
 
 
-const char *OracleResultSet_getColumnName(T R, int column) {
+static const char *_getColumnName(T R, int column) {
         assert(R);
         if (R->columnCount < column)
                 return NULL;
@@ -277,7 +258,7 @@ const char *OracleResultSet_getColumnName(T R, int column) {
 }
 
 
-long OracleResultSet_getColumnSize(T R, int columnIndex) {
+static long _getColumnSize(T R, int columnIndex) {
         OCIParam* pard = NULL;
         ub4 char_semantics = 0;
         sb4 status;
@@ -300,38 +281,52 @@ long OracleResultSet_getColumnSize(T R, int columnIndex) {
 }
 
 
-int OracleResultSet_next(T R) {
+static void _setFetchSize(T R, int rows) {
         assert(R);
-        if ((R->row < 0) || ((R->maxRow > 0) && (R->row >= R->maxRow)))
+        assert(rows > 0);
+        R->lastError = OCIAttrSet(R->stmt, OCI_HTYPE_STMT, (void*)&rows, (ub4)sizeof(ub4), OCI_ATTR_PREFETCH_ROWS, R->err);
+        if (R->lastError != OCI_SUCCESS)
+                DEBUG("OCIAttrSet -- %s\n", OraclePreparedStatement_getLastError(R->lastError, R->err));
+        R->fetchSize = rows;
+}
+
+
+static int _getFetchSize(T R) {
+        assert(R);
+        return R->fetchSize;
+}
+
+
+static bool _next(T R) {
+        assert(R);
+        if ((R->currentRow < 0) || ((R->maxRows > 0) && (R->currentRow >= R->maxRows)))
                 return false;
         R->lastError = OCIStmtFetch2(R->stmt, R->err, 1, OCI_FETCH_NEXT, 0, OCI_DEFAULT);
-        if (R->lastError == OCI_NO_DATA) 
+        if (R->lastError == OCI_NO_DATA)
                 return false;
         if (R->lastError != OCI_SUCCESS && R->lastError != OCI_SUCCESS_WITH_INFO)
                 THROW(SQLException, "%s", OraclePreparedStatement_getLastError(R->lastError, R->err));
         if (R->lastError == OCI_SUCCESS_WITH_INFO)
-                DEBUG("OracleResultSet_next Error %d, '%s'\n", R->lastError, OraclePreparedStatement_getLastError(R->lastError, R->err));
-        R->row++;
+                DEBUG("_next Error %d, '%s'\n", R->lastError, OraclePreparedStatement_getLastError(R->lastError, R->err));
+        R->currentRow++;
         return ((R->lastError == OCI_SUCCESS) || (R->lastError == OCI_SUCCESS_WITH_INFO));
 }
 
 
-int OracleResultSet_isnull(T R, int columnIndex) {
+static bool _isnull(T R, int columnIndex) {
         assert(R);
         int i = checkAndSetColumnIndex(columnIndex, R->columnCount);
-        return R->columns[i].isNull;
+        return R->columns[i].isNull != 0;
 }
 
 
-const char *OracleResultSet_getString(T R, int columnIndex) {
+static const char *_getString(T R, int columnIndex) {
         assert(R);
         int i = checkAndSetColumnIndex(columnIndex, R->columnCount);
         if (R->columns[i].isNull)
                 return NULL;
-        if (R->columns[i].date)
-        {
-                if (!_toString(R, i))
-                {
+        if (R->columns[i].date) {
+                if (!_toString(R, i)) {
                         THROW(SQLException, "%s", OraclePreparedStatement_getLastError(R->lastError, R->err));
                 }
         }
@@ -341,7 +336,7 @@ const char *OracleResultSet_getString(T R, int columnIndex) {
 }
 
 
-const void *OracleResultSet_getBlob(T R, int columnIndex, int *size) {
+static const void *_getBlob(T R, int columnIndex, int *size) {
         assert(R);
         int i = checkAndSetColumnIndex(columnIndex, R->columnCount);
         if (R->columns[i].isNull)
@@ -357,8 +352,8 @@ const void *OracleResultSet_getBlob(T R, int columnIndex, int *size) {
         do {
                 read_bytes = 0;
                 read_chars = 0;
-                R->lastError = OCILobRead2(R->svc, R->err, R->columns[i].lob_loc, &read_bytes, &read_chars, 1, 
-                                R->columns[i].buffer + total_bytes, LOB_CHUNK_SIZE, piece, NULL, NULL, 0, SQLCS_IMPLICIT);
+                R->lastError = OCILobRead2(R->svc, R->err, R->columns[i].lob_loc, &read_bytes, &read_chars, 1,
+                                           R->columns[i].buffer + total_bytes, LOB_CHUNK_SIZE, piece, NULL, NULL, 0, SQLCS_IMPLICIT);
                 if (read_bytes) {
                         total_bytes += read_bytes;
                         piece = OCI_NEXT_PIECE;
@@ -374,6 +369,22 @@ const void *OracleResultSet_getBlob(T R, int columnIndex, int *size) {
         return (const void *)R->columns[i].buffer;
 }
 
-#ifdef PACKAGE_PROTECTED
-#pragma GCC visibility pop
-#endif
+
+/* ------------------------------------------------------------------------- */
+
+
+const struct Rop_T oraclerops = {
+        .name           = "oracle",
+        .free           = _free,
+        .getColumnCount = _getColumnCount,
+        .getColumnName  = _getColumnName,
+        .getColumnSize  = _getColumnSize,
+        .setFetchSize   = _setFetchSize,
+        .getFetchSize   = _getFetchSize,
+        .next           = _next,
+        .isnull         = _isnull,
+        .getString      = _getString,
+        .getBlob        = _getBlob
+        // getTimestamp and getDateTime is handled in ResultSet
+};
+
