@@ -100,8 +100,18 @@ static bool _doConnect(T C, char **error) {
                 StringBuffer_append(C->sb, "dbname='%s' ", URL_getPath(url) + 1);
         else
                 ERROR("no database specified in URL");
-        /* Options */
+        /* SSL Options */
         StringBuffer_append(C->sb, "sslmode='%s' ", IS(URL_getParameter(url, "use-ssl"), "true") ? "require" : "disable");
+        if (URL_getParameter(url, "ssl-ca")) {
+                StringBuffer_append(C->sb, "sslrootcert='%s' ", URL_getParameter(url, "ssl-ca"));
+        }
+        if (URL_getParameter(url, "ssl-cert")) {
+                StringBuffer_append(C->sb, "sslcert='%s' ", URL_getParameter(url, "ssl-cert"));
+        }
+        if (URL_getParameter(url, "ssl-key")) {
+                StringBuffer_append(C->sb, "sslkey='%s' ", URL_getParameter(url, "ssl-key"));
+        }
+        /* Other Options */
         if (URL_getParameter(url, "connect-timeout")) {
                 TRY
                         StringBuffer_append(C->sb, "connect_timeout=%d ", Str_parseInt(URL_getParameter(url, "connect-timeout")));
@@ -109,7 +119,7 @@ static bool _doConnect(T C, char **error) {
                         ERROR("invalid connect timeout value");
                 END_TRY;
         } else
-                StringBuffer_append(C->sb, "connect_timeout=%d ", SQL_DEFAULT_TIMEOUT/MSEC_PER_SEC);
+                StringBuffer_append(C->sb, "connect_timeout=%lld ", SQL_DEFAULT_TIMEOUT/MSEC_PER_SEC);
         if (URL_getParameter(url, "application-name"))
                 StringBuffer_append(C->sb, "application_name='%s' ", URL_getParameter(url, "application-name"));
         /* Connect */
@@ -185,11 +195,6 @@ static bool _beginTransactionType(T C, TRANSACTION_TYPE type) {
 }
 
 
-static bool _beginTransaction(T C) {
-    return _beginTransactionType(C, TRANSACTION_DEFAULT);
-}
-
-
 static bool _commit(T C) {
 	assert(C);
         PGresult *res = PQexec(C->db, "COMMIT TRANSACTION;");
@@ -284,7 +289,6 @@ const struct Cop_T postgresqlcops = {
         .free                   = _free,
         .ping                   = _ping,
         .setQueryTimeout        = _setQueryTimeout,
-        .beginTransaction       = _beginTransaction,
         .beginTransactionType   = _beginTransactionType,
         .commit                 = _commit,
         .rollback               = _rollback,
