@@ -70,6 +70,20 @@ static int _options(URL_T url) {
         } else {
                 options |= SQLITE_OPEN_NOMUTEX;
         }
+        /*
+         * If ENABLE_SQLITE_SHARED_CACHE is defined during compilation,
+         * shared-cache mode is always enabled regardless of the URL parameter.
+         * This is specifically used for builds where shared-cache must always
+         * be on to ensure consistent behavior and prevent database lock issues.
+         * When not defined, the 'shared-cache' URL parameter controls this setting.
+         */
+#if ENABLE_SQLITE_SHARED_CACHE
+        options |= SQLITE_OPEN_SHAREDCACHE;
+#else
+        if (Str_parseBool(URL_getParameter(url, "shared-cache"))) {
+                options |= SQLITE_OPEN_SHAREDCACHE;
+        }
+#endif
         return options;
 }
 
@@ -100,18 +114,11 @@ static sqlite3 *_doConnect(Connection_T delegator, char **error) {
 static bool _setProperties(T C, char **error) {
         URL_T url = Connection_getURL(C->delegator);
         const char **properties = URL_getParameterNames(url);
+        const char *handled_properties[] = {"serialized", "shared-cache", NULL};
         if (properties) {
                 StringBuffer_clear(C->sb);
                 for (int i = 0; properties[i]; i++) {
-                        if (IS(properties[i], "heap_limit")) { // There is no PRAGMA for heap limit as of sqlite-3.7.0, so we make it a configurable property using "heap_limit" [kB]
-#if defined(HAVE_SQLITE3_SOFT_HEAP_LIMIT64)
-                                sqlite3_soft_heap_limit64(Str_parseInt(URL_getParameter(url, properties[i])) * 1024);
-#elif defined(HAVE_SQLITE3_SOFT_HEAP_LIMIT)
-                                sqlite3_soft_heap_limit(Str_parseInt(URL_getParameter(url, properties[i])) * 1024);
-#else
-                                DEBUG("heap_limit not supported by your sqlite3 version, please consider upgrading sqlite3\n");
-#endif
-                        } else if (IS(properties[i], "serialized")) {
+                        if (Str_member(properties[i], handled_properties)) {
                                 continue; // Handled in _doConnect, ignore
                         } else {
                                 StringBuffer_append(C->sb, "PRAGMA %s = %s; ", properties[i], URL_getParameter(url, properties[i]));
@@ -192,11 +199,6 @@ static bool _beginTransactionType(T C, TRANSACTION_TYPE type) {
 }
 
 
-static bool _beginTransaction(T C) {
-    return _beginTransactionType(C, TRANSACTION_DEFAULT);
-}
-
-
 static bool _commit(T C) {
         assert(C);
         C->lastError = zdb_sqlite3_exec(C->db, "COMMIT TRANSACTION;");
@@ -280,7 +282,6 @@ const struct Cop_T sqlite3cops = {
         .free 		        = _free,
         .ping		        = _ping,
         .setQueryTimeout        = _setQueryTimeout,
-        .beginTransaction       = _beginTransaction,
         .beginTransactionType   = _beginTransactionType,
         .commit                 = _commit,
         .rollback	        = _rollback,
