@@ -128,15 +128,16 @@ long long Time_milli(void);
 /**
  * Suspends the calling process or thread for the specified
  * duration in microseconds. If sleep is interrupted by a signal,
- * the function aborts sleep and returns false.
- * @param microseconds The duration of the sleep in microseconds.
- * @return true if sleep was completed, false if sleep was interrupted
- * by a signal.
+ * the function aborts sleep and returns the number of remaining
+ * microseconds.
+ * @param microseconds The duration of the sleep in microseconds
+ * @return 0 if sleep was completed, -1 if microseconds is invalid
+ *         (negative or would overflow timespec on 32-bit systems),
+ *         or remaining microseconds if interrupted by a signal
  */
-bool Time_usleep(long long microseconds);
+long long Time_usleep(long long microseconds);
 
 //@}
 
 
-#undef T
 #endif
