@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2016 dragon jiang<jianlinlong@gmail.com>
- * Copyright (C) 2019-2024 Tildeslash Ltd.
+ * Copyright (C) 2019-2025 Tildeslash Ltd.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files(the "Software"), to deal
@@ -40,13 +40,11 @@
 #include <unordered_map>
 
 /**
- *
  * @brief zdbpp.h - C++ Interface for libzdb
  *
  * <center><img src="database++.png" class="resp-img" style="width:700px"></center>
  *
- * This interface provides a C++ wrapper for libzdb, offering a convenient and 
- * type-safe way to interact with various SQL databases from C++ applications.
+ * A modern, type-safe way to interact with various SQL databases from C++ applications.
  *
  * ## Features
  *
@@ -1256,17 +1254,17 @@ namespace zdb {
      * execute statements: execute() is used to execute SQL
      * statements that do not return a result set. Such statements are INSERT,
      * UPDATE or DELETE. executeQuery() is used to execute a SQL
-     * SELECT statement and return a result set. These methods can only handle
-     * values which can be expressed as C-strings. If you need to handle binary
-     * data, such as inserting a blob value into the database, use a
-     * PreparedStatement object to execute the SQL statement. The factory method
-     * prepareStatement() is used to obtain a PreparedStatement object.
+     * SELECT statement and return a result set. These methods can handle
+     * various data types, including binary data, by automatically creating
+     * a PreparedStatement when arguments are provided. For more complex
+     * scenarios or when reusing statements, you can explicitly create a
+     * PreparedStatement object using the prepareStatement() method.
      *
      * The method executeQuery() will return an empty ResultSet (not null)
-     * if the SQL statement did not return any values. A ResultSet is valid until the
-     * next call to Connection execute or until the Connection is returned
-     * to the ConnectionPool. If an error occurs during execution, an sql_exception
-     * is thrown.
+     * if the SQL statement did not return any values. A ResultSet is valid 
+     * until the next call to Connection execute or until the Connection is
+     * returned to the ConnectionPool. If an error occurs during execution,
+     * an sql_exception is thrown.
      *
      * Any SQL statement that changes the database (basically, any SQL
      * command other than SELECT) will automatically start a transaction
@@ -1447,7 +1445,7 @@ namespace zdb {
          *
          * @param type The transaction isolation level (default: TRANSACTION_DEFAULT).
          *             @see TRANSACTION_TYPE enum for available options.
-         * @throws SQLException If a database error occurs or if a transaction is already in progress.
+         * @throws sql_exception If a database error occurs or if a transaction is already in progress.
          * @note All transactions must be ended with either commit() or rollback().
          *       Nested transactions are not supported.
          */
@@ -1465,7 +1463,7 @@ namespace zdb {
         
         /**
          * @brief Commits the current transaction.
-         * @throws SQLException If a database error occurs.
+         * @throws sql_exception If a database error occurs.
          */
         void commit() { except_wrapper(Connection_commit(t_)); }
         
@@ -1475,13 +1473,36 @@ namespace zdb {
          * This method will first call clear() before performing the rollback to
          * clear any statements in progress such as selects.
          *
-         * @throws SQLException If a database error occurs.
+         * @throws sql_exception If a database error occurs.
          */
         void rollback() { except_wrapper(Connection_rollback(t_)); }
         
         /**
          * @brief Gets the last inserted row ID for auto-increment columns.
          * @return The last inserted row ID.
+         *
+         * @note This function works as expected for MySQL and SQLite.
+         * For PostgreSQL and Oracle, this function may not return the expected value.
+         * For these databases, it's recommended to use the RETURNING clause in your
+         * INSERT statement instead.
+         *
+         * Example usage for different database systems:
+         *
+         * @code
+         * // For MySQL and SQLite:
+         * con.execute("INSERT INTO users(name) VALUES(?)", "Min-seo");
+         * long long id = con.lastRowId();
+         *
+         * // For PostgreSQL (assuming id is the auto increment column name):
+         * ResultSet r = con.executeQuery("INSERT INTO users(name) VALUES(?) RETURNING id", "Min-seo");
+         * long long id = r.next() ? r.getLLong(1) : -1;
+         *
+         * // For Oracle:
+         * ResultSet r = con.executeQuery("INSERT INTO users(name) VALUES(?) RETURNING ROWID", "Min-seo");
+         * long long id = r.next() ? r.getLLong(1) : -1;
+         * @endcode
+         *
+         * @see ResultSet
          */
         [[nodiscard]] long long lastRowId() noexcept { return Connection_lastRowId(t_); }
         
@@ -1582,7 +1603,7 @@ namespace zdb {
          *
          * @param sql The SQL statement to prepare.
          * @return A PreparedStatement object.
-         * @throws SQLException If a database error occurs during preparation.
+         * @throws sql_exception If a database error occurs during preparation.
          *
          * Example usage:
          * @code
@@ -1690,10 +1711,12 @@ namespace zdb {
      * For SQLite, the URL should specify a database file. SQLite uses [pragma commands](http://sqlite.org/pragma.html) for performance tuning and other special purpose
      * database commands. Pragma syntax in the form `name=value` can be added as properties to the URL. In addition to pragmas, the following properties are supported:
      *
-     * - `heap_limit=value` - Make SQLite auto-release unused memory
-     *   if memory usage goes above the specified value [KB].
      * - `serialized=true` - Make SQLite switch to serialized mode
      *   if value is true, otherwise multi-thread mode is used (the default).
+     * - `shared-cache=true` - Make SQLite use shared-cache if value is true.
+     *   Using shared cache can significantly reduce database lock errors in
+     *   some scenarios where two or more connections might write to the database.
+     *   It is also recommended to build libsqlite and libzdb with unlock  notify.
      *
      * Example URL for SQLite (with recommended pragmas):
      * ```
@@ -1808,6 +1831,13 @@ namespace zdb {
         /// @name Properties
         /// @{
 
+        /**
+         * @brief Retrieves the database type for this ConnectionPool
+         * @return The CONNECTIONPOOL_TYPE representing the database backend for this ConnectionPool
+         * @see CONNECTIONPOOL_TYPE
+         */
+        CONNECTIONPOOL_TYPE getType() const noexcept { return ConnectionPool_getType(t_); }
+
         /**
          * @brief Gets the URL of the connection pool.
          * @return The URL of the connection pool.
