@@ -22,30 +22,30 @@ Exception_T B = {"BException"};
 Exception_T C = {"CException"};
 Exception_T D = {"DException"};
 
-void throwA(void) {
+static void throwA(void) {
         THROW(A, "A");
 }
 
-void throwB(void) {
+static void throwB(void) {
         THROW(B, "B");
 }
 
-void throwC(void) {
+static void throwC(void) {
         THROW(C, "C");
 }
 
-void throwD(void) {
+static void throwD(void) {
         THROW(D, "D");
 }
 
-void indirectA(void) {
+static void indirectA(void) {
         throwA();
 }
 
 /* Throw and catch exceptions and check that we get the expected exception. 
  * If the exception stack is corrupt this should be detected
  */
-void *thread(void *args) {
+static void *thread(void *args) {
         TRY
                 THROW(A, "A");
                 assert(false); // Should not be reached
@@ -326,6 +326,37 @@ int main(void) {
         }
         printf("=> Test12: OK\n\n");
         
+        printf("=> Test14: Double interpretation of format strings during RETHROW\n");
+        {
+                TRY
+                {
+                        TRY
+                        {
+                                TRY
+                                {
+                                        // Trigger exception
+                                        printf("\t1st level TRY: throw exception with string argument 'hello%%sally'\n");
+                                        THROW(AssertException, "1st level TRY: %s", "hello%sally");
+                                }
+                                END_TRY;
+                        }
+                        FINALLY
+                        {
+                                printf("\t2nd level TRY: FINALLY will rethrow the 1st level exception '%s'\n", Exception_frame.message);
+                                // The FINALLY will RETHROW the exception, which leads to Exception_throw()
+                        }
+                        END_TRY;
+                }
+                ELSE
+                {
+                        // Catch the exception
+                        printf("\t3nd level TRY: catch the 1st level exception '%s'\n", Exception_frame.message);
+                        assert(IS(Exception_frame.message, "1st level TRY: hello%sally"));
+                }
+                END_TRY;
+        }
+        printf("=> Test14: OK\n\n");
+        
         printf("============> Exception Tests: OK\n\n");
 
         return 0;
