@@ -127,6 +127,7 @@ static void testPool(const char *testURL) {
                 url = URL_new(testURL);
                 pool = ConnectionPool_new(url);
                 assert(pool);
+                assert(ConnectionPool_getType(pool) > CONNECTIONPOOL_NONE);
                 ConnectionPool_setReaper(pool, 0); // disable reaper
                 ConnectionPool_setAbortHandler(pool, TabortHandler);
                 ConnectionPool_start(pool);
@@ -141,9 +142,9 @@ static void testPool(const char *testURL) {
                 // Assert that the last insert statement added one row
                 assert(Connection_rowsChanged(con) == 1);
                 /* Assert that last row id works for MySQL and SQLite. Neither Oracle nor PostgreSQL
-                 support last row id directly. The way to do this in PostgreSQL is to use 
-                 currval() or return the id on insert. */
-                if (IS(URL_getProtocol(url), "sqlite") || IS(URL_getProtocol(url), "mysql")) 
+                 support last row id directly. The way to do this in PostgreSQL is to return the id
+                 on insert and in libzdb execute the statement using executeQuery */
+                if (IS(URL_getProtocol(url), "sqlite") || IS(URL_getProtocol(url), "mysql"))
                         assert(Connection_lastRowId(con) == 12);
                 Connection_commit(con);
                 printf("\tResult: table zild_t successfully created\n");
@@ -377,7 +378,6 @@ static void testPool(const char *testURL) {
 
         printf("=> Test8: Exceptions handling\n");
         {
-                int i;
                 Connection_T con;
                 ResultSet_T result;
                 url = URL_new(testURL);
@@ -404,7 +404,7 @@ static void testPool(const char *testURL) {
                 TRY
                 {
                         Connection_beginTransaction(con);
-                        for (i = 0; data[i]; i++) 
+                        for (int i = 0; data[i]; i++)
                                 Connection_execute(con, "insert into zild_t (name, percent) values('%s', %d.%d);", data[i], i+1, i);
                         Connection_commit(con);
                         printf("\tResult: table zild_t successfully created\n");
@@ -422,7 +422,6 @@ static void testPool(const char *testURL) {
                 assert((con = ConnectionPool_getConnection(pool)));
                 TRY
                 {
-                        int i, j;
                         const char *bg[]= {"Starbuck", "Sharon Valerii",
                                 "Number Six", "Gaius Baltar", "William Adama",
                                 "Lee \"Apollo\" Adama", "Laura Roslin", 0};
@@ -435,6 +434,7 @@ static void testPool(const char *testURL) {
                            will throw an SQLException and transfer the control
                            to the exception handler
                         */
+                        int i, j;
                         for (i = 0, j = 42; bg[i]; i++, j++) {
                                 PreparedStatement_setString(p, 1, bg[i]);
                                 PreparedStatement_execute(p);
@@ -724,7 +724,7 @@ int main(void) {
         URL_T url;
         char buf[BSIZE];
         char *help = "Please enter a valid database connection URL and press ENTER\n"
-                    "E.g. sqlite:///tmp/sqlite.db?synchronous=off&heap_limit=2000\n"
+                    "E.g. sqlite:///tmp/sqlite.db?synchronous=normal\n"
                     "E.g. mysql://localhost:3306/test?user=root&password=root\n"
                     "E.g. postgresql://localhost:5432/test?user=root&password=root\n"
                     "E.g. oracle://scott:tiger@localhost:1521/servicename\n"
